﻿namespace Upload.Web.Models
{
    using System;

    using Upload.Web.Images;

    /// <summary>
    /// 
    /// </summary>
    public class UserAppService
    {
        /// <summary>
        /// 上传头像。
        /// </summary>
        /// <param name="userId">用户编号。</param>
        /// <param name="uploadImage">上传图片信息。</param>
        /// <returns></returns>
        public ViewIconImage UploadIcon(int userId, UploadImage uploadImage)
        {
            string newFileName;

            var view = ImageManager.Current.LoadImage(uploadImage, () => UserIconManager.Current.GetSaveDirectory(userId) + userId, out newFileName);

            if (view == null)
            {
                throw new Exception("头像上传失败。");
            }

            //保存头像后缀名。
            ViewIconImage iconImage = new ViewIconImage();

            iconImage.ViewWidth = view.ViewWidth;
            iconImage.ViewHeight = view.ViewHeight;
            iconImage.Image = UserIconManager.Current.GetIcon(userId, newFileName, IconSize.Normal);
            iconImage.BigImage = UserIconManager.Current.GetIcon(userId, newFileName, IconSize.Big);
            iconImage.SmallImage = UserIconManager.Current.GetIcon(userId, newFileName, IconSize.Small);

            return iconImage;
        }

        /// <summary>
        /// 修改头像。
        /// </summary>
        /// <param name="userId">用户编号。</param>
        /// <param name="ext">头像后缀名。</param>
        /// <param name="cutImage">裁剪图片输入信息。</param>
        public ChangeIconStatus ChangeIcon(int userId, string ext, CutImageModel cutImage)
        {
            if (userId <= 0)
            {
                return ChangeIconStatus.LoginInvalid;
            }

            string sourceImagePath = string.Empty;

            if (!string.IsNullOrWhiteSpace(ext))
            {
                string savePath = UserIconManager.Current.GetSaveDirectory(userId);
                sourceImagePath = savePath + userId.ToString() + ext;
                ImageManager.Current.CutImage(sourceImagePath, savePath, (int)IconSize.Big, true, cutImage, userId.ToString(), (int)IconSize.Small);

                return ChangeIconStatus.Success;
            }

            return ChangeIconStatus.NotUpload;
        }
    }
}